@@ -112,6 +112,7 @@ TEST_F(ColladaLoader, LoadZeroCount)
       common::testing::TestFile("data", "zero_count.dae"));
   ASSERT_TRUE(mesh);
 #ifndef _WIN32
+  common::Console::Root().RawLogger().flush();
   std::string log = LogContent();
 
   // Expect no errors about missing values
@@ -503,3 +504,20 @@ TEST_F(ColladaLoader, LoadCylinderAnimatedFrom3dsMax)
   EXPECT_TRUE(anim->HasNode("Bone02"));
   delete mesh;
 }
+
+/////////////////////////////////////////////////
+// Load animation without a name
+TEST_F(ColladaLoader, NoAnimName)
+{
+  common::ColladaLoader loader;
+
+  std::string meshFilename =
+    common::testing::TestFile("data", "box_with_no_animation_name.dae");
+
+  common::Mesh *mesh = loader.Load(meshFilename);
+  common::SkeletonPtr skeleton = mesh->MeshSkeleton();
+  ASSERT_EQ(1u, skeleton->AnimationCount());
+  common::SkeletonAnimation *anim = skeleton->Animation(0);
+  auto animName = anim->Name();
+  EXPECT_EQ(animName, "animation1");
+}
